@@ -5,7 +5,7 @@
 
 package Convert::ASN1::parser;
 
-;# $Id: parser.pm,v 1.3 2001/02/05 22:31:41 gbarr Exp $
+;# $Id: parser.pm,v 1.4 2001/07/31 17:03:14 gbarr Exp $
 
 use strict;
 use Convert::ASN1 qw(:all);
@@ -667,7 +667,7 @@ sub compile_one {
       $op->[cTAG] = defined($op->[cTAG]) ? asn_encode_tag($op->[cTAG]): $base_type{$type}->[0];
     }
     else {
-      die "Internal error\n" unless exists $tree->{$type};
+      die "Unknown type '$type'\n" unless exists $tree->{$type};
       my $ref = compile_one(
 		  $tree,
 		  $tree->{$type},
